@@ -1,9 +1,9 @@
-predict.lognet=function(object,newx,s=object$lambda,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,...){
+predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,offset,...){
   type=match.arg(type)
   a0=t(as.matrix(object$a0))
   rownames(a0)="(Intercept)"
   nbeta=rbind2(a0,object$beta)
-  if(!missing(s)){
+  if(!is.null(s)){
     vnames=dimnames(nbeta)[[1]]
     dimnames(nbeta)=list(NULL,NULL)
    lambda=object$lambda
@@ -18,7 +18,12 @@ predict.lognet=function(object,newx,s=object$lambda,type=c("link","response","co
   if(type=="coefficients")return(nbeta)
   if(type=="nonzero")return(nonzeroCoef(nbeta[-1,,drop=FALSE],bystep=TRUE))
   nfit=as.matrix(cbind2(1,newx)%*%nbeta)
-  switch(type,
+  if(object$offset){
+    if(missing(offset))stop("No offset provided for prediction, yet used in fit of glmnet",call.=FALSE)
+    if(is.matrix(offset)&&dim(offset)[[2]]==2)offset=offset[,2]
+    nfit=nfit+array(offset,dim=dim(nfit))
+  }
+switch(type,
          response={
            pp=exp(-nfit)
            1/(1+pp)
